@@ -2,11 +2,13 @@ import os, sys, pygame
 from .originator import *
 from .careTaker import *
 from .orientation import *
+from .grid.test import *
 from random import randint
 import pkg_resources
 
 class Agent:
     def __init__(self, name, begin, end, color):
+        self.test = Test()
         self._name = name
         self.orientation = Orientation.NORTH
         self.num = id(self)
