@@ -12,10 +12,7 @@ if cmd_subfolder_grid not in sys.path:
 
 from .parser import Parser
 from .grid import Grid
-'''
-Objectif :
-Parser le bon environnement et retourner les qtables/rewtable a partir du nom passer au constructeur
-'''
+
 
 class EnvBuilder:
     def __init__(self, name: str, gui: bool):
